A command line function tester

# litio

## how to use

example 1:
```
$ litio main.py --function say_hello --params say_to joe --function-type function
hello joe!
```



example 2:
```
$ litio main.py --function concatenate --params striing_a "hello" string_b " world" --function-type function
hello world
```

example 3:
```
$ litio main.py -f pow -p base 2 exponent 3 -t function --print-return
8
```